==> bash-config_23.06.01.tar.xz: mx-bashrc-config/translations/bash-config_rue.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="rue">
<context>
    <name>AliasTab</name>
    <message>
        <location filename="../aliastab.ui" line="71"/>
        <source>Add</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../aliastab.ui" line="82"/>
        <source>Remove</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>OtherTab</name>
    <message>
        <location filename="../othertab.ui" line="35"/>
        <source>History</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../othertab.ui" line="41"/>
        <source>Custom</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../othertab.ui" line="63"/>
        <source>Infinite</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../othertab.ui" line="75"/>
        <source>Executable Paths</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../othertab.ui" line="84"/>
        <source>Edit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../othertab.ui" line="97"/>
        <source>Add</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../othertab.ui" line="108"/>
        <source>Remove</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PromptTab</name>
    <message>
        <location filename="../prompttab_fix.ui" line="44"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Change what gives you your prompt.&lt;/p&gt;&lt;p&gt;Default - Use what prompt you had before.&lt;/p&gt;&lt;p&gt;Fancy Prompt - Uses the MX Fancy Prompt utility&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="152"/>
        <source>Make The Larger Prompts Smaller</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="159"/>
        <source>Muted Colors</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="166"/>
        <source>Disable Unicode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="173"/>
        <source>Use Double Lines</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="180"/>
        <source>Use Bold Lines</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="187"/>
        <source>No Colors(Overrides All Other Color Options)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="194"/>
        <source>Use Parentheses Instead Of Square Brackets</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="201"/>
        <source>Make the Larger Prompts Smaller Elsewhere</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="225"/>
        <source>Time Format</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="267"/>
        <source>Date Format</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="315"/>
        <source>Right Margin</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="351"/>
        <source>Extra Newlines Before Prompt</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="380"/>
        <source>Prompt Text</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="409"/>
        <source>Title Text</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="429"/>
        <source>Remove all newlines</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="456"/>
        <source>Edit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="478"/>
        <source>Add</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="501"/>
        <source>Remove</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="518"/>
        <source>Up</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="535"/>
        <source>Down</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../prompttab.cpp" line="543"/>
        <source>Foreground Color</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../prompttab.cpp" line="544"/>
        <source>Background Color</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../prompttab.cpp" line="545"/>
        <source>Bold</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../window_fix.ui" line="35"/>
        <source>About</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../window_fix.ui" line="46"/>
        <source>Help</source>
        <translation>Помоч</translation>
    </message>
    <message>
        <location filename="../window_fix.ui" line="85"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Applies Changes.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../window_fix.ui" line="88"/>
        <source>Apply</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../window_fix.ui" line="99"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Closes the application.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../window_fix.ui" line="102"/>
        <source>Close</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../window.cpp" line="48"/>
        <source>An easy way to configure your ~/.bashrc and bash prompt</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../window.cpp" line="260"/>
        <location filename="../window.cpp" line="264"/>
        <location filename="../window.cpp" line="268"/>
        <source>Bash Config</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> bash-config_23.07.01.tar.xz: mx-bashrc-config/translations/bash-config_rue.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="rue">
<context>
    <name>AliasTab</name>
    <message>
        <location filename="../aliastab.ui" line="71"/>
        <source>Add</source>
        <translation>Придати</translation>
    </message>
    <message>
        <location filename="../aliastab.ui" line="82"/>
        <source>Remove</source>
        <translation>Удалити</translation>
    </message>
</context>
<context>
    <name>OtherTab</name>
    <message>
        <location filename="../othertab.ui" line="35"/>
        <source>History</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../othertab.ui" line="41"/>
        <source>Custom</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../othertab.ui" line="63"/>
        <source>Infinite</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../othertab.ui" line="75"/>
        <source>Executable Paths</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../othertab.ui" line="84"/>
        <source>Edit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../othertab.ui" line="97"/>
        <source>Add</source>
        <translation>Придати</translation>
    </message>
    <message>
        <location filename="../othertab.ui" line="108"/>
        <source>Remove</source>
        <translation>Удалити</translation>
    </message>
</context>
<context>
    <name>PromptTab</name>
    <message>
        <location filename="../prompttab_fix.ui" line="44"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Change what gives you your prompt.&lt;/p&gt;&lt;p&gt;Default - Use what prompt you had before.&lt;/p&gt;&lt;p&gt;Fancy Prompt - Uses the MX Fancy Prompt utility&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="152"/>
        <source>Make The Larger Prompts Smaller</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="159"/>
        <source>Muted Colors</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="166"/>
        <source>Disable Unicode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="173"/>
        <source>Use Double Lines</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="180"/>
        <source>Use Bold Lines</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="187"/>
        <source>No Colors(Overrides All Other Color Options)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="194"/>
        <source>Use Parentheses Instead Of Square Brackets</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="201"/>
        <source>Make the Larger Prompts Smaller Elsewhere</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="225"/>
        <source>Time Format</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="267"/>
        <source>Date Format</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="315"/>
        <source>Right Margin</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="351"/>
        <source>Extra Newlines Before Prompt</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="380"/>
        <source>Prompt Text</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="409"/>
        <source>Title Text</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="429"/>
        <source>Remove all newlines</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="456"/>
        <source>Edit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="478"/>
        <source>Add</source>
        <translation>Придати</translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="501"/>
        <source>Remove</source>
        <translation>Удалити</translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="518"/>
        <source>Up</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="535"/>
        <source>Down</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../prompttab.cpp" line="543"/>
        <source>Foreground Color</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../prompttab.cpp" line="544"/>
        <source>Background Color</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../prompttab.cpp" line="545"/>
        <source>Bold</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../window_fix.ui" line="35"/>
        <source>About</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../window_fix.ui" line="46"/>
        <source>Help</source>
        <translation>Помоч</translation>
    </message>
    <message>
        <location filename="../window_fix.ui" line="85"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Applies Changes.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../window_fix.ui" line="88"/>
        <source>Apply</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../window_fix.ui" line="99"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Closes the application.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../window_fix.ui" line="102"/>
        <source>Close</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../window.cpp" line="48"/>
        <source>An easy way to configure your ~/.bashrc and bash prompt</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../window.cpp" line="260"/>
        <location filename="../window.cpp" line="264"/>
        <location filename="../window.cpp" line="268"/>
        <source>Bash Config</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
